@@ -9,7 +9,8 @@ from vivarium.core.process import (
     Generator
 )
 from vivarium.core.composition import (
-    compartment_hierarchy_experiment,
+    compose_experiment,
+    GENERATORS_KEY,
     PROCESS_OUT_DIR,
 )
 from vivarium.core.experiment import pp
@@ -163,7 +164,7 @@ def test_division():
 
     # declare the hierarchy
     hierarchy = {
-        'processes': [
+        GENERATORS_KEY: [
             {
                 'type': TimelineProcess,
                 'config': {'timeline': timeline},
@@ -174,20 +175,21 @@ def test_division():
             }
         ],
         'agents': {
-            'generators': [
-                {
-                    'name': agent_id,
+            agent_id: {
+                GENERATORS_KEY: {
                     'type': ToyAgent,
                     'config': {'agent_id': agent_id}
                 },
-            ]
+            }
         }
     }
 
     # configure experiment
-    experiment = compartment_hierarchy_experiment(
+    settings = {}
+    experiment = compose_experiment(
         hierarchy=hierarchy,
-        initial_state=initial_state)
+        initial_state=initial_state,
+        settings=settings)
 
     # run simulation
     experiment.update(time_total)
@@ -209,7 +211,7 @@ def run_division():
     if not os.path.exists(out_dir):
         os.makedirs(out_dir)
     output = test_division()
-    pp(output)
+    # pp(output)
 
 
 if __name__ == '__main__':
